"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _containers = _interopRequireDefault(require("./containers"));

var _rows = _interopRequireDefault(require("./rows"));

var _blocs = _interopRequireDefault(require("./blocs"));

var _fractions = _interopRequireDefault(require("./fractions"));

var _columns = _interopRequireDefault(require("./columns"));

var _containersQuery = _interopRequireDefault(require("./containers-query"));

var _blocsQuery = _interopRequireDefault(require("./blocs-query"));

var _fractionsQuery = _interopRequireDefault(require("./fractions-query"));

var _columnsQuery = _interopRequireDefault(require("./columns-query"));

var _rulesQuery = _interopRequireDefault(require("./rules-query"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// import util from 'util';
var _default = (e, opts, {
  rule,
  root,
  atRule
}) => {
  const rootNode = root();

  if (e.containers.length) {
    const container = (0, _containers.default)(e.containers, opts, {
      rule
    });
    rootNode.append(container);
  }

  if (e.rows.length) {
    const {
      row,
      rowClearFix
    } = (0, _rows.default)(e.rows, opts, {
      rule
    });
    rootNode.append(row);
    rootNode.append(rowClearFix);
  }

  if (e.blocs.length) {
    const bloc = (0, _blocs.default)(e.blocs, opts, {
      rule
    });
    rootNode.append(bloc);
  }

  if (e.fractions.length) {
    const fraction = (0, _fractions.default)(e.fractions, opts, {
      rule
    });
    rootNode.append(fraction);
  }

  if (e.fractions[0] && e.fractions[0].length) {
    const frs = (0, _fractionsQuery.default)(e.fractions[0], opts, {
      rule
    });
    frs.forEach(fraction => {
      rootNode.append(fraction);
    });
  }

  if (e.columns.length) {
    const columnsGap = (0, _columns.default)(e.columns, opts, {
      rule
    });
    rootNode.append(columnsGap);
    const cols = (0, _columnsQuery.default)(e.columns, opts, 0, {
      rule
    });
    cols.forEach(col => {
      rootNode.append(col);
    });
  }

  if (e.rules[0]) {
    const res = (0, _rulesQuery.default)(e.rules[0]);
    res.forEach(r => {
      rootNode.append(r);
    });
  }

  for (let breakpoint = 1; breakpoint <= opts.max; breakpoint += 1) {
    const queryWidth = breakpoint * opts.width - opts.gutter + 2 * opts.padding;
    const mediaQuery = atRule({
      name: 'media',
      params: `(min-width: ${queryWidth}rem)`
    });

    if (e.blocs.length) {
      const {
        blocWidths,
        blocLefts,
        blocRights
      } = (0, _blocsQuery.default)(e.blocs, opts, breakpoint, {
        rule
      });
      blocWidths.forEach(bloc => {
        mediaQuery.append(bloc);
      });
      blocLefts.forEach(bloc => {
        mediaQuery.append(bloc);
      });
      blocRights.forEach(bloc => {
        mediaQuery.append(bloc);
      });
    }

    if (breakpoint >= opts.min) {
      if (e.containers.length) {
        const res = (0, _containersQuery.default)(e.containers, opts, breakpoint, {
          rule
        });
        mediaQuery.append(res);
      }

      if (e.fractions[breakpoint]) {
        const frs = (0, _fractionsQuery.default)(e.fractions[breakpoint], opts, {
          rule
        });
        frs.forEach(fraction => {
          mediaQuery.append(fraction);
        });
      }

      if (e.columns && e.columns.length) {
        const cols = (0, _columnsQuery.default)(e.columns, opts, breakpoint, {
          rule
        });
        cols.forEach(col => {
          mediaQuery.append(col);
        });
      }

      if (e.rules[breakpoint]) {
        const res = (0, _rulesQuery.default)(e.rules[breakpoint]);
        res.forEach(r => {
          mediaQuery.append(r);
        });
      }
    }

    if (mediaQuery.nodes && mediaQuery.nodes.length) {
      // console.log('booo', util.inspect(mediaQuery.nodes.length, false, null))
      rootNode.append(mediaQuery);
    }
  }

  return rootNode;
};

exports.default = _default;